package com.example.androidapplication

import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.androidapplication.databinding.ActivityAnnouncementsBinding
import com.example.androidapplication.network.ApiService
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class AnnouncementsActivity : AppCompatActivity() {
    private lateinit var binding: ActivityAnnouncementsBinding
    private lateinit var adapter: AnnouncementsAdapter

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityAnnouncementsBinding.inflate(layoutInflater)
        setContentView(binding.root)

        setupRecyclerView()
        loadAnnouncements()
    }

    private fun setupRecyclerView() {
        adapter = AnnouncementsAdapter()
        binding.recyclerView.apply {
            layoutManager = LinearLayoutManager(this@AnnouncementsActivity)
            adapter = this@AnnouncementsActivity.adapter
        }
    }

    private fun loadAnnouncements() {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val response = ApiService.getInstance(this@AnnouncementsActivity)
                    .getAnnouncements()

                withContext(Dispatchers.Main) {
                    adapter.submitList(response)
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    // Afficher une erreur
                }
            }
        }
    }
}