package com.example.androidapplication

import android.graphics.Color
import android.os.Build
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.example.androidapplication.databinding.ItemCalendarDayBinding
import com.example.androidapplication.databinding.ItemEventBinding
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.network.CalendarEvent
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import java.text.SimpleDateFormat
import java.time.LocalDate
import java.time.ZoneId
import java.util.Locale

class CalendarAdapter(
    private var events: List<CalendarEvent> = emptyList(),
    private val onItemClick: (CalendarEvent) -> Unit
) : RecyclerView.Adapter<CalendarAdapter.EventViewHolder>() {

    private val dateFormat = SimpleDateFormat("EEE d MMM", Locale.getDefault())
    private val timeFormat = SimpleDateFormat("HH:mm", Locale.getDefault())

    inner class EventViewHolder(val binding: ItemEventBinding) :
        RecyclerView.ViewHolder(binding.root)

    fun updateEvents(newEvents: List<CalendarEvent>) {
        events = newEvents.sorted()
        notifyDataSetChanged()
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): EventViewHolder {
        val binding = ItemEventBinding.inflate(
            LayoutInflater.from(parent.context),
            parent,
            false
        )
        return EventViewHolder(binding)
    }

    override fun onBindViewHolder(holder: EventViewHolder, position: Int) {
        val event = events[position]
        with(holder.binding) {
            eventTitle.text = event.title
            eventDate.text = dateFormat.format(event.start_date)
            eventTime.text = "${timeFormat.format(event.start_date)} - ${timeFormat.format(event.end_date)}"
            eventDescription.text = event.description

            root.setOnClickListener { onItemClick(event) }
        }
    }

    override fun getItemCount() = events.size
}