package com.example.androidapplication

import android.content.ContentValues.TAG
import android.util.Log
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.example.androidapplication.network.GlobalMessage
import java.text.SimpleDateFormat
import java.util.*
import com.example.androidapplication.databinding.ItemMessageSentBinding
import com.example.androidapplication.databinding.ItemMessageReceivedBinding

class ChatAdapter : RecyclerView.Adapter<RecyclerView.ViewHolder>() {
    private val VIEW_TYPE_ME = 1
    private val VIEW_TYPE_OTHER = 2

    private var messages = emptyList<GlobalMessage>()

    inner class MeMessageHolder(val binding: ItemMessageSentBinding) :
        RecyclerView.ViewHolder(binding.root)

    inner class OtherMessageHolder(val binding: ItemMessageReceivedBinding) :
        RecyclerView.ViewHolder(binding.root)

    override fun getItemViewType(position: Int): Int {
        if (messages[position].is_me == 1) {
            return VIEW_TYPE_ME
        } else {
            return VIEW_TYPE_OTHER
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return if (viewType == VIEW_TYPE_ME) {
            MeMessageHolder(
                ItemMessageSentBinding.inflate(
                    LayoutInflater.from(parent.context),
                    parent,
                    false
                )
            )
        } else {
            OtherMessageHolder(
                ItemMessageReceivedBinding.inflate(
                    LayoutInflater.from(parent.context),
                    parent,
                    false
                )
            )
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val message = messages[position]
        val dateFormat = SimpleDateFormat("HH:mm", Locale.FRANCE)

        when (holder) {
            is MeMessageHolder -> {
                holder.binding.messageText.text = message.message
                holder.binding.timeText.text = dateFormat.format(message.created_at)
            }
            is OtherMessageHolder -> {
                holder.binding.messageText.text = message.message
                holder.binding.timeText.text = dateFormat.format(message.created_at)
                holder.binding.usernameText.text = message.username
            }
        }
    }

    override fun getItemCount() = messages.size

    fun submitList(newList: List<GlobalMessage>) {
        messages = newList
        notifyDataSetChanged()
    }
}