package com.example.androidapplication

import android.app.AlertDialog
import android.app.DatePickerDialog
import android.app.Dialog
import android.app.TimePickerDialog
import android.os.Bundle
import android.widget.DatePicker
import android.widget.TimePicker
import androidx.fragment.app.DialogFragment
import com.example.androidapplication.databinding.DialogNewEventBinding
import java.text.SimpleDateFormat
import java.util.*

class NewEventDialogFragment(
    private val onEventCreated: (String, String, Date, Date) -> Unit
) : DialogFragment(), DatePickerDialog.OnDateSetListener, TimePickerDialog.OnTimeSetListener {

    private lateinit var binding: DialogNewEventBinding
    private var isStartDate = true
    private var tempDate = Calendar.getInstance()
    private lateinit var startDate: Date
    private lateinit var endDate: Date

    companion object {
        fun newInstance(onEventCreated: (String, String, Date, Date) -> Unit): NewEventDialogFragment {
            return NewEventDialogFragment(onEventCreated)
        }
    }

    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        binding = DialogNewEventBinding.inflate(layoutInflater)

        // Initialisation des dates par défaut
        val now = Calendar.getInstance()
        startDate = now.time
        now.add(Calendar.HOUR, 1)
        endDate = now.time
        updateDateDisplays()

        // Sélecteurs de date/heure
        binding.startDateButton.setOnClickListener {
            isStartDate = true
            showDatePicker()
        }

        binding.endDateButton.setOnClickListener {
            isStartDate = false
            showDatePicker()
        }

        return AlertDialog.Builder(requireContext())
            .setTitle("Nouvel événement")
            .setView(binding.root)
            .setPositiveButton("Créer") { _, _ ->
                val title = binding.titleInput.text.toString()
                val description = binding.descriptionInput.text.toString()
                if (title.isNotBlank()) {
                    onEventCreated(title, description, startDate, endDate)
                }
            }
            .setNegativeButton("Annuler", null)
            .create()
    }

    private fun showDatePicker() {
        val calendar = if (isStartDate) Calendar.getInstance().apply { time = startDate }
        else Calendar.getInstance().apply { time = endDate }

        DatePickerDialog(
            requireContext(),
            this,
            calendar.get(Calendar.YEAR),
            calendar.get(Calendar.MONTH),
            calendar.get(Calendar.DAY_OF_MONTH)
        ).show()
    }

    override fun onDateSet(view: DatePicker?, year: Int, month: Int, day: Int) {
        tempDate.set(year, month, day)
        showTimePicker()
    }

    private fun showTimePicker() {
        val calendar = if (isStartDate) Calendar.getInstance().apply { time = startDate }
        else Calendar.getInstance().apply { time = endDate }

        TimePickerDialog(
            requireContext(),
            this,
            calendar.get(Calendar.HOUR_OF_DAY),
            calendar.get(Calendar.MINUTE),
            true
        ).show()
    }

    override fun onTimeSet(view: TimePicker?, hour: Int, minute: Int) {
        tempDate.set(Calendar.HOUR_OF_DAY, hour)
        tempDate.set(Calendar.MINUTE, minute)

        if (isStartDate) {
            startDate = tempDate.time
            // Ajuster automatiquement la date de fin si nécessaire
            if (startDate.after(endDate)) {
                endDate = tempDate.time
                val cal = Calendar.getInstance().apply { time = endDate }
                cal.add(Calendar.HOUR, 1)
                endDate = cal.time
            }
        } else {
            endDate = tempDate.time
        }

        updateDateDisplays()
    }

    private fun updateDateDisplays() {
        val dateFormat = SimpleDateFormat("dd/MM/yyyy HH:mm", Locale.getDefault())
        binding.startDateButton.text = dateFormat.format(startDate)
        binding.endDateButton.text = dateFormat.format(endDate)
    }
}