package com.example.androidapplication

import android.content.Intent
import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.androidapplication.databinding.ActivityNotesBinding
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.network.Note
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class NotesActivity : AppCompatActivity() {
    private lateinit var binding: ActivityNotesBinding
    private lateinit var adapter: NotesAdapter

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityNotesBinding.inflate(layoutInflater)
        setContentView(binding.root)

        setupToolbar()
        setupRecyclerView()
        loadNotes()
        setupFab()
    }

    private fun setupToolbar() {
//        binding.toolbar.homeButton.setOnClickListener {
//            startActivity(Intent(this, UserHomeActivity::class.java))
//        }
//        binding.toolbar.toolbarTitle.text = "Mes Notes"
    }

    private fun setupRecyclerView() {
        adapter = NotesAdapter()
        binding.recyclerView.apply {
            layoutManager = LinearLayoutManager(this@NotesActivity)
            adapter = this@NotesActivity.adapter
        }
    }

    fun loadNotes() {
        CoroutineScope(Dispatchers.IO).launch {
            try {
                val notes = ApiService.getInstance(this@NotesActivity).getNotes()
                withContext(Dispatchers.Main) {
                    adapter.submitList(notes)
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    // Gérer l'erreur
                }
            }
        }
    }

    private fun setupFab() {
        binding.fab.setOnClickListener {
            NoteDialogFragment().show(supportFragmentManager, "NewNoteDialog")
        }
    }
}