package com.example.androidapplication

import android.content.Intent
import android.os.Bundle
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.androidapplication.databinding.ActivitySettingsBinding
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.network.Note
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class SettingsActivity : AppCompatActivity() {
    private lateinit var binding: ActivitySettingsBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivitySettingsBinding.inflate(layoutInflater)
        setContentView(binding.root)

        setupToolbar()
        setupInputs()
    }

    private fun setupToolbar() {
//        binding.toolbar.toolbarTitle.text = "Paramètres"
//        binding.toolbar.homeButton.setOnClickListener { finish() }
    }

    private fun setupInputs() {
        binding.usernameField.setEndIconOnClickListener {
            updateUsername(binding.usernameEdit.text.toString())
        }

        binding.emailField.setEndIconOnClickListener {
            updateEmail(binding.emailEdit.text.toString())
        }

        binding.passwordButton.setOnClickListener {
            updatePassword(
                binding.currentPasswordEdit.text.toString(),
                binding.newPasswordEdit.text.toString()
            )
        }
    }

    private fun updateUsername(newUsername: String) {
        if (newUsername.isBlank()) return

        CoroutineScope(Dispatchers.IO).launch {
            try {
                ApiService.getInstance(this@SettingsActivity)
                    .updateUsername(mapOf("newUsername" to newUsername))
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@SettingsActivity, "Nom d'utilisateur mis à jour", Toast.LENGTH_SHORT).show()
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@SettingsActivity, "Erreur: ${e.message}", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }

    private fun updateEmail(newEmail: String) {
        if (newEmail.isBlank()) return

        CoroutineScope(Dispatchers.IO).launch {
            try {
                ApiService.getInstance(this@SettingsActivity)
                    .updateEmail(mapOf("newEmail" to newEmail))
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@SettingsActivity, "Email mis à jour", Toast.LENGTH_SHORT).show()
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@SettingsActivity, "Erreur: ${e.message}", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }

    private fun updatePassword(current: String, new: String) {
        if (current.isBlank() || new.isBlank()) return

        CoroutineScope(Dispatchers.IO).launch {
            try {
                ApiService.getInstance(this@SettingsActivity)
                    .updatePassword(mapOf(
                        "currentPassword" to current,
                        "newPassword" to new
                    ))
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@SettingsActivity, "Mot de passe mis à jour", Toast.LENGTH_SHORT).show()
                    binding.currentPasswordEdit.text?.clear()
                    binding.newPasswordEdit.text?.clear()
                }
            } catch (e: Exception) {
                withContext(Dispatchers.Main) {
                    Toast.makeText(this@SettingsActivity, "Erreur: ${e.message}", Toast.LENGTH_SHORT).show()
                }
            }
        }
    }
}