package com.example.androidapplication

import android.os.Bundle
import android.view.Menu
import com.google.android.material.snackbar.Snackbar
import com.google.android.material.navigation.NavigationView
import androidx.navigation.findNavController
import androidx.navigation.ui.AppBarConfiguration
import androidx.navigation.ui.navigateUp
import androidx.navigation.ui.setupActionBarWithNavController
import androidx.navigation.ui.setupWithNavController
import androidx.drawerlayout.widget.DrawerLayout
import androidx.appcompat.app.AppCompatActivity
import android.content.Intent
import android.view.View
import com.example.androidapplication.auth.LoginActivity
import com.example.androidapplication.databinding.ActivityUserHomeBinding
import com.example.androidapplication.network.UserData
import com.example.androidapplication.utils.SharedPreferencesHelper

class UserHomeActivity : AppCompatActivity() {
    private var currentUser: UserData? = null
    private lateinit var binding: ActivityUserHomeBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityUserHomeBinding.inflate(layoutInflater)
        setContentView(binding.root)

        currentUser = SharedPreferencesHelper.getUserData(this)

        // Récupérer le nom d'utilisateur
        val username = intent.getStringExtra("username") ?: "Utilisateur"
        binding.title.text = "Bonjour $username"

        setupMenuButtons()
    }

    private fun setupMenuButtons() {
        binding.btnCalendar.setOnClickListener {
            startActivity(Intent(this, CalendarActivity::class.java))
        }

        binding.btnAnnouncements.setOnClickListener {
            startActivity(Intent(this, AnnouncementsActivity::class.java))
        }

        binding.btnChat.setOnClickListener {
            startActivity(Intent(this, ChatActivity::class.java))
        }

        binding.btnNotes.setOnClickListener {
            startActivity(Intent(this, NotesActivity::class.java))
        }

        binding.btnSettings.setOnClickListener {
            startActivity(Intent(this, SettingsActivity::class.java))
        }

        binding.btnUsers.visibility = if (currentUser?.role == "admin") View.VISIBLE else View.GONE
        binding.btnUsers.setOnClickListener {
            startActivity(Intent(this, UsersActivity::class.java))
        }
    }
}