package com.example.androidapplication.auth

import android.app.Application
import androidx.lifecycle.AndroidViewModel
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.network.AuthResponse
import com.example.androidapplication.network.LoginRequest
import com.example.androidapplication.utils.SharedPreferencesHelper
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import kotlinx.coroutines.launch
import java.lang.Exception

class AuthViewModel(application: Application, private val apiService: ApiService) : AndroidViewModel(application) {

    private val context = application.applicationContext

    fun login(username: String, password: String, onResult: (AuthResponse) -> Unit) {
        viewModelScope.launch {
            try {
                val response = apiService.login(LoginRequest(username, password))
                if (response.success && response.token != null && response.user != null) {
                    // Sauvegarder le token et les infos utilisateur
                    SharedPreferencesHelper.saveAuthToken(response.token, context)
                    SharedPreferencesHelper.saveUserData(response.user, context)
                }
                onResult(response)
            } catch (e: Exception) {
                onResult(AuthResponse(false, "Network error: ${e.message}", null, null))
            }
        }
    }
}