package com.example.androidapplication.auth

import android.app.Application
import com.example.androidapplication.network.ApiService
import com.example.androidapplication.utils.SharedPreferencesHelper
import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.widget.Toast
import androidx.activity.viewModels
import androidx.lifecycle.ViewModelProvider
import com.example.androidapplication.databinding.ActivityLoginBinding
import androidx.lifecycle.ViewModel
import android.view.View
import com.example.androidapplication.UserHomeActivity
import com.example.androidapplication.network.User
import com.example.androidapplication.network.UserData
import android.content.ContentValues.TAG

class LoginActivity : AppCompatActivity() {

    private lateinit var binding: ActivityLoginBinding
    private val viewModel: AuthViewModel by viewModels {
        AuthViewModelFactory(application as Application, ApiService.getInstance(this))
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityLoginBinding.inflate(layoutInflater)
        setContentView(binding.root)

        // Vérifier si l'utilisateur est déjà connecté
        //val token = SharedPreferencesHelper.getAuthToken(this)
//        if (token != null) {
//            //redirectBasedOnRole()
//            return
//        }

        setupListeners()
    }

    private fun setupListeners() {
        binding.loginButton.setOnClickListener {
            val username = binding.usernameEditText.text.toString().trim()
            val password = binding.passwordEditText.text.toString().trim()

            if (username.isEmpty() || password.isEmpty()) {
                Toast.makeText(this, "Veuillez remplir tous les champs", Toast.LENGTH_SHORT).show()
                return@setOnClickListener
            }

            binding.progressBar.visibility = View.VISIBLE
            binding.loginButton.isEnabled = false

            viewModel.login(username, password) { response ->
                binding.progressBar.visibility = View.GONE
                binding.loginButton.isEnabled = true

                if (response.success) {
                    Toast.makeText(this, "Connexion réussie", Toast.LENGTH_SHORT).show()
                    redirectBasedOnRole(response.user!!)
                } else {
                    Toast.makeText(
                        this,
                        response.message ?: "Échec de la connexion",
                        Toast.LENGTH_SHORT
                    ).show()
                }
            }
        }
    }

    private fun redirectBasedOnRole(user: UserData) {
        when (user.role) {
            "admin" -> {
                // Rediriger vers l'interface admin
                val intent = Intent(this, UserHomeActivity::class.java).apply {
                    putExtra("username", user.username)
                }
                startActivity(intent)
            }
            "user" -> {
                // Rediriger vers l'interface utilisateur
                val intent = Intent(this, UserHomeActivity::class.java).apply {
                    putExtra("username", user.username)
                }
                startActivity(intent)
            }
            else -> {
                Toast.makeText(this, "Rôle utilisateur inconnu", Toast.LENGTH_SHORT).show()
            }
        }
        finish()
    }
}

class AuthViewModelFactory(
    private val application: Application,
    private val apiService: ApiService
) : ViewModelProvider.AndroidViewModelFactory(application) {

    override fun <T : ViewModel> create(modelClass: Class<T>): T {
        if (modelClass.isAssignableFrom(AuthViewModel::class.java)) {
            return AuthViewModel(application, apiService) as T
        }
        throw IllegalArgumentException("Unknown ViewModel class")
    }
}