package com.example.androidapplication.network

import android.content.Context
import com.example.androidapplication.utils.SharedPreferencesHelper
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.http.Body
import retrofit2.http.Path
import retrofit2.http.POST
import retrofit2.http.GET
import retrofit2.http.PUT
import retrofit2.http.DELETE
import retrofit2.http.Query
import java.util.concurrent.TimeUnit

interface ApiService {
    @POST("auth/login")
    suspend fun login(@Body request: LoginRequest): AuthResponse

    @GET("announcements")
    suspend fun getAnnouncements(): List<Announcement>

    @GET("notes")
    suspend fun getNotes(): List<Note>

    @POST("notes")
    suspend fun createNote(@Body note: Map<String, String>): retrofit2.Response<Unit>

    @POST("chat")
    suspend fun sendGlobalMessage(@Body message: Map<String, String>): retrofit2.Response<Unit>

    @GET("chat")
    suspend fun getGlobalMessages(): List<GlobalMessage>

    @PUT("settings/username")
    suspend fun updateUsername(@Body body: Map<String, String>): retrofit2.Response<Unit>

    @PUT("settings/email")
    suspend fun updateEmail(@Body body: Map<String, String>): retrofit2.Response<Unit>

    @PUT("settings/password")
    suspend fun updatePassword(@Body body: Map<String, String>): retrofit2.Response<Unit>

    @POST("events")
    suspend fun createEvent(
        @Body request: CreateEventRequest
    ): retrofit2.Response<EventResponse>

    @GET("events")
    suspend fun getEvents(): List<CalendarEvent>

    @GET("users")
    suspend fun getUsers(): List<User>

    @POST("users")
    suspend fun createUser(
        @Body request: CreateUserRequest
    ): retrofit2.Response<Unit>

    @DELETE("users/{id}")
    suspend fun deleteUser(@Path("id") id: Int): retrofit2.Response<Unit>

    companion object {
        private var instance: ApiService? = null

        fun getInstance(context: Context): ApiService {
            if (instance == null) {
                val serverUrl = "http://148.113.194.48:8000"

                val loggingInterceptor = HttpLoggingInterceptor().apply {
                    level = HttpLoggingInterceptor.Level.BODY
                }

                val client = OkHttpClient.Builder()
                    .addInterceptor { chain ->
                        val request = chain.request().newBuilder()
                            .addHeader("Authorization", "Bearer ${SharedPreferencesHelper.getAuthToken(context)}")
                            .build()
                        chain.proceed(request)
                    }
                    .addInterceptor(loggingInterceptor)
                    .connectTimeout(30, TimeUnit.SECONDS)
                    .readTimeout(30, TimeUnit.SECONDS)
                    .writeTimeout(30, TimeUnit.SECONDS)
                    .build()

                val retrofit = Retrofit.Builder()
                    .baseUrl(serverUrl)
                    .client(client)
                    .addConverterFactory(GsonConverterFactory.create())
                    .build()

                instance = retrofit.create(ApiService::class.java)
            }
            return instance!!
        }
    }
}