package com.example.androidapplication.network

import retrofit2.http.Query
import java.util.Date

data class AuthResponse(
    val success: Boolean,
    val message: String?,
    val token: String?,
    val user: UserData?
)

data class UserData(
    val id: Int,
    val username: String,
    val email: String,
    val profile_picture: String?,
    val role: String,
    val grade: String?,
    val created_at: String,
    val updated_at: String
)

data class User(
    val id: Int,
    val username: String,
    val email: String,
    val password_hash: String? = null,
    val profile_picture: String?,
    val role: String, // "admin" ou "user"
    val grade: String?,
    val created_at: String,
    val updated_at: String
) {
    fun isAdmin(): Boolean = role == "admin"
}

data class LoginRequest(
    val username: String,
    val password: String
)

data class Announcement(
    val id: Int,
    val title: String,
    val content: String,
    val author: String,
    val createdAt: String
)

data class Note(
    val id: Int,
    val note: String,
    val author: String,
    val created_at: Date
)

data class GlobalMessage(
    val message: String,
    val created_at: Date,
    val username: String,
    val is_me: Int
)

data class CalendarEvent(
    val id: Int,
    val title: String,
    val description: String,
    val start_date: Date,
    val end_date: Date,
    val status: String
) : Comparable<CalendarEvent> {
    override fun compareTo(other: CalendarEvent): Int {
        return this.start_date.compareTo(other.start_date)
    }
}

data class CreateEventRequest(
    val title: String,
    val description: String,
    val start_date: String, // Format ISO 8601
    val end_date: String
)

data class EventResponse(
    val id: Int,
    val title: String,
)

data class CreateUserRequest(
    val email: String,
    val username: String,
    val password: String,
    val role: String
)