package com.example.androidapplication.utils

import android.content.Context
import android.content.SharedPreferences
import com.example.androidapplication.network.UserData
import com.google.gson.Gson

object SharedPreferencesHelper {
    private const val PREFS_NAME = "TeamSyncPrefs"
    private const val AUTH_TOKEN = "auth_token"
    private const val USER_DATA = "user_data"

    private fun getSharedPreferences(context: Context): SharedPreferences {
        return context.getSharedPreferences(PREFS_NAME, Context.MODE_PRIVATE)
    }

    fun saveAuthToken(token: String, context: Context) {
        getSharedPreferences(context).edit().putString(AUTH_TOKEN, token).apply()
    }

    fun getAuthToken(context: Context): String? {
        return getSharedPreferences(context).getString(AUTH_TOKEN, null)
    }

    fun saveUserData(user: UserData, context: Context) {
        val json = Gson().toJson(user)
        getSharedPreferences(context).edit().putString(USER_DATA, json).apply()
    }

    fun getUserData(context: Context): UserData? {
        val json = getSharedPreferences(context).getString(USER_DATA, null)
        return if (json != null) Gson().fromJson(json, UserData::class.java) else null
    }

    fun clearUserData(context: Context) {
        getSharedPreferences(context).edit().clear().apply()
    }
}